# Arkindex base Worker

An easy to use Python 3 high level API client, to build ML tasks.

This is an open-source project, licensed using [the MIT license](https://opensource.org/license/mit/).

## Documentation

The [documentation](https://workers.arkindex.org/) is made with [Antora](https://antora.org/) and is hosted by [GitLab Pages](https://docs.gitlab.com/ee/user/project/pages/).

## Create a new worker using our template

```shell
pip install --user cookiecutter
cookiecutter git@gitlab.teklia.com:workers/base-worker.git
```
